@@ -86,7 +86,7 @@ class Application(Gtk.Application, NightApplication):
         Gtk.Application.__init__(
             self,
             application_id=app_id,
-            flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE)
+            flags=Gio.ApplicationFlags.HANDLES_COMMAND_LINE | Gio.ApplicationFlags.HANDLES_OPEN)
         self.set_property("register-session", True)
         # Fix proxy for python
         proxy = GLib.environ_getenv(GLib.get_environ(), "all_proxy")
@@ -119,6 +119,7 @@ class Application(Gtk.Application, NightApplication):
                              GLib.OptionArg.NONE, "Show TLS info",
                              None)
         self.connect("activate", self.__on_activate)
+        self.connect("open", self.__on_open)
         self.connect("handle-local-options", self.__on_handle_local_options)
         self.connect("command-line", self.__on_command_line)
 
@@ -761,6 +762,23 @@ class Application(Gtk.Application, NightApplication):
         active_window.container.add_webview_for_uri(self.start_page, LoadingType.FOREGROUND, True)
         active_window.present()
 
+    def __on_open(self, app, files, _n_files, _hint):
+        if not self.windows:
+            self.__init()
+            self.__restore_state()
+
+        if not self.windows:
+            active_window = self.get_new_window()
+        else:
+            active_window = self.active_window
+
+        for file in files:
+            loading_type = wanted_loading_type(
+                len(active_window.container.webviews))
+            active_window.container.add_webview_for_uri(file.get_uri(), loading_type, False)
+
+        active_window.present()
+
     def __on_content_blocker_set_filter(self, content_blocker, content_filter):
         """
             Add filter to content manager
